@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -19,6 +19,7 @@ Results (:mod:`qiskit_nature.results`)
 Qiskit Nature results such as for electronic and vibrational structure. Algorithms
 may extend these to provide algorithm specific aspects in their result.
 
+
 Results
 =======
 
@@ -30,6 +31,16 @@ Results
    BOPESSamplerResult
    ElectronicStructureResult
    VibrationalStructureResult
+   LatticeModelResult
+   ProteinFoldingResult
+
+Protein Folding Result support classes
+--------------------------------------
+
+.. autosummary::
+   :toctree:
+
+   utils
 
 """
 
@@ -37,6 +48,8 @@ from .bopes_sampler_result import BOPESSamplerResult
 from .eigenstate_result import EigenstateResult
 from .electronic_structure_result import DipoleTuple, ElectronicStructureResult
 from .vibrational_structure_result import VibrationalStructureResult
+from .lattice_model_result import LatticeModelResult
+from .protein_folding_result import ProteinFoldingResult
 
 __all__ = [
     "BOPESSamplerResult",
@@ -44,4 +57,6 @@ __all__ = [
     "EigenstateResult",
     "ElectronicStructureResult",
     "VibrationalStructureResult",
+    "LatticeModelResult",
+    "ProteinFoldingResult",
 ]
