@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -12,7 +12,7 @@
 
 """BOPES Sampler result"""
 
-from typing import List, Dict
+from typing import List, Dict, Union
 
 from .eigenstate_result import EigenstateResult
 
@@ -23,7 +23,7 @@ class BOPESSamplerResult:
     def __init__(
         self,
         points: List[float],
-        energies: List[float],
+        energies: List[List[float]],
         raw_results: Dict[float, EigenstateResult],
     ) -> None:
         """
@@ -44,9 +44,18 @@ class BOPESSamplerResult:
         return self._points
 
     @property
-    def energies(self) -> List[float]:
+    def energies(self) -> Union[List[float], List[List[float]]]:
         """returns list of energies."""
-        return self._energies
+        # In general, self._energies is a list over all the sampling points, of lists over all
+        # eigenstates of the eigenstate energies at these sampling points.
+        # If the BOPES is based on a `GroundStateSolver`, then the inner lists have only one entry
+        # and the `List[List[float]]]` is flattened into a `List[float]`.
+        formatted_energies: Union[List[float], List[List[float]]]
+        if len(self._energies[0]) == 1:
+            formatted_energies = [self._energies[k][0] for k in range(len(self._energies))]
+        else:
+            formatted_energies = self._energies
+        return formatted_energies
 
     @property
     def raw_results(self) -> Dict[float, EigenstateResult]:
