@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -19,7 +19,9 @@ import warnings
 
 from test import QiskitNatureTestCase
 
-from qiskit import Aer
+import numpy as np
+
+import qiskit
 from qiskit.utils import algorithm_globals, QuantumInstance
 from qiskit.algorithms.optimizers import COBYLA
 
@@ -112,16 +114,37 @@ class TestBosonicESCCalculation(QiskitNatureTestCase):
     def test_vqe_uvccsd_factory(self):
         """Test with VQE plus UVCCSD"""
         optimizer = COBYLA(maxiter=5000)
-        solver = VQEUVCCFactory(
-            QuantumInstance(Aer.get_backend("aer_simulator_statevector")),
-            optimizer=optimizer,
+        quantum_instance = QuantumInstance(
+            backend=qiskit.BasicAer.get_backend("statevector_simulator"),
+            seed_simulator=algorithm_globals.random_seed,
+            seed_transpiler=algorithm_globals.random_seed,
         )
+        solver = VQEUVCCFactory(quantum_instance=quantum_instance, optimizer=optimizer)
         gsc = GroundStateEigensolver(self.qubit_converter, solver)
         esc = QEOM(gsc, "sd")
         results = esc.solve(self.vibrational_problem)
         for idx, energy in enumerate(self.reference_energies):
             self.assertAlmostEqual(results.computed_vibrational_energies[idx], energy, places=1)
 
+    def test_vqe_uvcc_factory_with_user_initial_point(self):
+        """Test VQEUVCCFactory when using it with a user defined initial point."""
+        initial_point = np.asarray([-7.35250290e-05, -9.73079292e-02, -5.43346282e-05])
+        optimizer = COBYLA(maxiter=1)
+        quantum_instance = QuantumInstance(
+            backend=qiskit.BasicAer.get_backend("statevector_simulator"),
+            seed_simulator=algorithm_globals.random_seed,
+            seed_transpiler=algorithm_globals.random_seed,
+        )
+        solver = VQEUVCCFactory(
+            quantum_instance=quantum_instance, optimizer=optimizer, initial_point=initial_point
+        )
+        gsc = GroundStateEigensolver(self.qubit_converter, solver)
+        esc = QEOM(gsc, "sd")
+        results = esc.solve(self.vibrational_problem)
+        np.testing.assert_array_almost_equal(
+            results.raw_result.ground_state_raw_result.optimal_point, initial_point
+        )
+
     def test_vqe_uvccsd_with_callback(self):
         """Test VQE UVCCSD with callback."""
 
@@ -129,10 +152,14 @@ class TestBosonicESCCalculation(QiskitNatureTestCase):
             print(f"iterations {nfev}: energy: {energy}")
 
         optimizer = COBYLA(maxiter=5000)
+
+        quantum_instance = QuantumInstance(
+            backend=qiskit.BasicAer.get_backend("statevector_simulator"),
+            seed_simulator=algorithm_globals.random_seed,
+            seed_transpiler=algorithm_globals.random_seed,
+        )
         solver = VQEUVCCFactory(
-            QuantumInstance(Aer.get_backend("aer_simulator_statevector")),
-            optimizer=optimizer,
-            callback=cb_callback,
+            quantum_instance=quantum_instance, optimizer=optimizer, callback=cb_callback
         )
         gsc = GroundStateEigensolver(self.qubit_converter, solver)
         esc = QEOM(gsc, "sd")
