@@ -14,9 +14,15 @@
 
 import unittest
 
-from test import QiskitNatureTestCase, requires_extra_library
+from test import QiskitNatureTestCase
+import warnings
+import numpy as np
 
+from qiskit_nature.hdf5 import load_from_hdf5
 from qiskit_nature.drivers.second_quantization import GaussianLogDriver, GaussianLogResult
+from qiskit_nature.properties.second_quantization.vibrational import VibrationalEnergy
+from qiskit_nature.properties.second_quantization.vibrational.integrals import VibrationalIntegrals
+import qiskit_nature.optionals as _optionals
 
 
 class TestDriverGaussianLog(QiskitNatureTestCase):
@@ -28,7 +34,7 @@ class TestDriverGaussianLog(QiskitNatureTestCase):
             "test_driver_gaussian_log_A03.txt", "drivers/second_quantization/gaussiand"
         )
 
-    @requires_extra_library
+    @unittest.skipIf(not _optionals.HAS_GAUSSIAN, "gaussian not available.")
     def test_log_driver(self):
         """Test the driver itself creates log and we can get a result"""
         driver = GaussianLogDriver(
@@ -131,41 +137,92 @@ class TestDriverGaussianLog(QiskitNatureTestCase):
         ]
         self.assertListEqual(qfc, expected)
 
+    def test_vibrational_energy(self):
+        """Test the VibrationalEnergy."""
+        result = GaussianLogResult(self.logfile)
+        vib_energy = result.get_vibrational_energy()
+        expected = load_from_hdf5(
+            self.get_resource_path(
+                "test_driver_gaussian_log_vibrational_energy.hdf5",
+                "drivers/second_quantization/gaussiand",
+            )
+        )
+
+        self.addTypeEqualityFunc(VibrationalIntegrals, self.compare_vibrational_integral)
+        self.addTypeEqualityFunc(VibrationalEnergy, self.compare_vibrational_energy)
+        self.assertEqual(vib_energy, expected)
+
+    def compare_vibrational_integral(
+        self, first: VibrationalIntegrals, second: VibrationalIntegrals, msg: str = None
+    ) -> None:
+        """Compares two VibrationalIntegral instances."""
+        if first.name != second.name:
+            raise self.failureException(msg)
+
+        if first._num_body_terms != second._num_body_terms:
+            raise self.failureException(msg)
+
+        for f_int, s_int in zip(first._integrals, second._integrals):
+            if not np.isclose(f_int[0], s_int[0]):
+                raise self.failureException(msg)
+
+            if not all(f == s for f, s in zip(f_int[1:], s_int[1:])):
+                raise self.failureException(msg)
+
+    def compare_vibrational_energy(
+        self, first: VibrationalEnergy, second: VibrationalEnergy, msg: str = None
+    ) -> None:
+        # pylint: disable=unused-argument
+        """Compares two VibrationalEnergy instances."""
+        for f_ints, s_ints in zip(
+            first._vibrational_integrals.values(), second._vibrational_integrals.values()
+        ):
+            self.compare_vibrational_integral(f_ints, s_ints)
+
     def test_watson_hamiltonian(self):
         """Test the watson hamiltonian"""
-        result = GaussianLogResult(self.logfile)
-        watson = result.get_watson_hamiltonian()
-        expected = [
-            [352.3005875, 2, 2],
-            [-352.3005875, -2, -2],
-            [631.6153975, 1, 1],
-            [-631.6153975, -1, -1],
-            [115.653915, 4, 4],
-            [-115.653915, -4, -4],
-            [115.653915, 3, 3],
-            [-115.653915, -3, -3],
-            [-15.341901966295344, 2, 2, 2],
-            [-88.2017421687633, 1, 1, 2],
-            [42.40478531359112, 4, 4, 2],
-            [26.25167512727164, 4, 3, 2],
-            [2.2874639206341865, 3, 3, 2],
-            [0.4207357291666667, 2, 2, 2, 2],
-            [4.9425425, 1, 1, 2, 2],
-            [1.6122932291666665, 1, 1, 1, 1],
-            [-4.194299375, 4, 4, 2, 2],
-            [-4.194299375, 3, 3, 2, 2],
-            [-10.20589125, 4, 4, 1, 1],
-            [-10.20589125, 3, 3, 1, 1],
-            [2.2973803125, 4, 4, 4, 4],
-            [2.7821204166666664, 4, 4, 4, 3],
-            [7.329224375, 4, 4, 3, 3],
-            [-2.7821200000000004, 4, 3, 3, 3],
-            [2.2973803125, 3, 3, 3, 3],
-        ]
-        for i, entry in enumerate(watson.data):
-            msg = f"mode[{i}]={entry} does not match expected {expected[i]}"
-            self.assertAlmostEqual(entry[0], expected[i][0], msg=msg)
-            self.assertListEqual(entry[1:], expected[i][1:], msg=msg)
+        msg_ref = (
+            "The get_watson_hamiltonian method is deprecated as of version 0.4.0 and "
+            "will be removed no sooner than 3 months after the release. Instead use the "
+            "get_vibrational_energy method Construct a VibrationalEnergy instead of the "
+            "deprecated WatsonHamiltonian directly."
+        )
+        with warnings.catch_warnings(record=True) as c_m:
+            warnings.simplefilter("always")
+            result = GaussianLogResult(self.logfile)
+            watson = result.get_watson_hamiltonian()
+            expected = [
+                [352.3005875, 2, 2],
+                [-352.3005875, -2, -2],
+                [631.6153975, 1, 1],
+                [-631.6153975, -1, -1],
+                [115.653915, 4, 4],
+                [-115.653915, -4, -4],
+                [115.653915, 3, 3],
+                [-115.653915, -3, -3],
+                [-15.341901966295344, 2, 2, 2],
+                [-88.2017421687633, 1, 1, 2],
+                [42.40478531359112, 4, 4, 2],
+                [26.25167512727164, 4, 3, 2],
+                [2.2874639206341865, 3, 3, 2],
+                [0.4207357291666667, 2, 2, 2, 2],
+                [4.9425425, 1, 1, 2, 2],
+                [1.6122932291666665, 1, 1, 1, 1],
+                [-4.194299375, 4, 4, 2, 2],
+                [-4.194299375, 3, 3, 2, 2],
+                [-10.20589125, 4, 4, 1, 1],
+                [-10.20589125, 3, 3, 1, 1],
+                [2.2973803125, 4, 4, 4, 4],
+                [2.7821204166666664, 4, 4, 4, 3],
+                [7.329224375, 4, 4, 3, 3],
+                [-2.7821200000000004, 4, 3, 3, 3],
+                [2.2973803125, 3, 3, 3, 3],
+            ]
+            for i, entry in enumerate(watson.data):
+                msg = f"mode[{i}]={entry} does not match expected {expected[i]}"
+                self.assertAlmostEqual(entry[0], expected[i][0], msg=msg)
+                self.assertListEqual(entry[1:], expected[i][1:], msg=msg)
+            self.assertEqual(str(c_m[0].message), msg_ref)
 
 
 if __name__ == "__main__":
