@@ -63,7 +63,7 @@ class TestVibrationalStructureProblem(QiskitNatureTestCase):
         num_modals = [num_modals] * num_modes
         vibrational_problem = VibrationalStructureProblem(self.driver, num_modals, truncation_order)
         second_quantized_ops = vibrational_problem.second_q_ops()
-        vibrational_op = second_quantized_ops[0]
+        vibrational_op = second_quantized_ops[vibrational_problem.main_property_name]
 
         with self.subTest("Check expected length of the list of second quantized operators."):
             assert len(second_quantized_ops) == expected_num_of_sec_quant_ops
@@ -83,7 +83,7 @@ class TestVibrationalStructureProblem(QiskitNatureTestCase):
         num_modals = [num_modals] * num_modes
         vibrational_problem = VibrationalStructureProblem(self.driver, num_modals, truncation_order)
         second_quantized_ops = vibrational_problem.second_q_ops()
-        vibrational_op = second_quantized_ops[0]
+        vibrational_op = second_quantized_ops[vibrational_problem.main_property_name]
 
         with self.subTest("Check expected length of the list of second quantized operators."):
             assert len(second_quantized_ops) == expected_num_of_sec_quant_ops
